Ensemble methods — Version 0.11.0.dev0

# Ensemble methods

The `imblearn.ensemble` module include methods generating under-sampled subsets combined inside an ensemble.

## Boosting algorithms

`EasyEnsembleClassifier`([n_estimators, ...]) | Bag of balanced boosted learners also known as EasyEnsemble.
`RUSBoostClassifier`([estimator, ...]) | Random under-sampling integrated in the learning of AdaBoost.

## Bagging algorithms

`BalancedBaggingClassifier`([estimator, ...]) | A Bagging classifier with additional balancing.
`BalancedRandomForestClassifier`([...]) | A balanced random forest classifier.

previous

SMOTETomek

next

EasyEnsembleClassifier